# Generated by Django 5.2.7 on 2025-10-25 15:05

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Hit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('path', models.CharField(db_index=True, max_length=500)),
                ('object_id', models.PositiveIntegerField(blank=True, null=True)),
                ('hits', models.PositiveBigIntegerField(default=0)),
                ('last_hit', models.DateTimeField(auto_now=True)),
                ('content_type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
            options={
                'indexes': [models.Index(fields=['path'], name='django_page_path_c76430_idx')],
                'unique_together': {('path', 'content_type', 'object_id')},
            },
        ),
    ]
